@@ -80,7 +80,10 @@ enum PLCType { BTE=0, TCD, STRS, OBJECT, TOKEN, BMKT, Unknown};
 struct Bookmark
 {
 	//! constructor
-	Bookmark() : m_id(-1), m_text(""), m_error("") {}
+	Bookmark()
+		: m_id(-1)
+		, m_text("")
+		, m_error("") {}
 	//! operator <<
 	friend std::ostream &operator<<(std::ostream &o, Bookmark const &tok);
 
@@ -102,27 +105,19 @@ std::ostream &operator<<(std::ostream &o, Bookmark const &bmk)
 struct Notes
 {
 	/** constructor */
-	Notes() : m_zoneNote(-1), m_zoneCorr(-1), m_type(WPSContentListener::FOOTNOTE), m_note(false), m_corr(0L), m_positions() {}
+	Notes()
+		: m_zoneNote(-1)
+		, m_zoneCorr(-1)
+		, m_type(WPSContentListener::FOOTNOTE)
+		, m_note(false)
+		, m_corr(nullptr)
+		, m_positions() {}
 	/** copy constructor */
-	Notes(Notes const &orig) :
-		m_zoneNote(-1), m_zoneCorr(-1), m_type(WPSContentListener::FOOTNOTE), m_note(false), m_corr(0L), m_positions()
-	{
-		*this = orig;
-	}
+	Notes(Notes const &) = default;
+	Notes(Notes &&) = default;
 	/** copy operator */
-	Notes &operator=(Notes const &orig)
-	{
-		if (this != &orig)
-		{
-			m_zoneNote = orig.m_zoneNote;
-			m_zoneCorr = orig.m_zoneCorr;
-			m_type = orig.m_type;
-			m_note = orig.m_note;
-			m_corr = orig.m_corr;
-			m_positions = orig.m_positions;
-		}
-		return *this;
-	}
+	Notes &operator=(Notes const &) = default;
+	Notes &operator=(Notes &&) = default;
 	WPSEntry getCorrespondanceEntry(long offset) const
 	{
 		WPSEntry res;
@@ -193,7 +188,7 @@ std::ostream &operator<<(std::ostream &o, Notes const &note)
 	size_t numPos = note.m_positions.size();
 	o << ": N=" << numPos-1;
 	o << ",ptrs=(" << std::hex;
-	for (size_t i = 0; i < numPos; i++) o << "0x" << note.m_positions[i] << ",";
+	for (auto const &pos : note.m_positions) o << "0x" << pos << ",";
 	o << ")" << std::dec;
 	return o;
 }
@@ -204,7 +199,12 @@ struct Object
 	enum Type { Unknown = 0, Table, Image };
 
 	//! constructor
-	Object() : m_type(Unknown), m_id(-1), m_size(), m_unknown(0), m_error("") {}
+	Object()
+		: m_type(Unknown)
+		, m_id(-1)
+		, m_size()
+		, m_unknown(0)
+		, m_error("") {}
 	//! operator <<
 	friend std::ostream &operator<<(std::ostream &o, Object const &obj);
 
@@ -251,7 +251,12 @@ std::ostream &operator<<(std::ostream &o, Object const &obj)
 struct Token
 {
 	//! constructor
-	Token() : m_type(WPSField::None), m_textLength(-1), m_unknown(-1), m_text(""), m_error("") {}
+	Token()
+		: m_type(WPSField::None)
+		, m_textLength(-1)
+		, m_unknown(-1)
+		, m_text("")
+		, m_error("") {}
 	//! operator <<
 	friend std::ostream &operator<<(std::ostream &o, Token const &tok);
 
@@ -309,7 +314,11 @@ std::ostream &operator<<(std::ostream &o, Token const &tok)
 struct DataPLC
 {
 	//! constructor
-	DataPLC(): m_name(""), m_type(Unknown), m_value(-1), m_error("") {}
+	DataPLC()
+		: m_name("")
+		, m_type(Unknown)
+		, m_value(-1)
+		, m_error("") {}
 	//! operator<<
 	friend std::ostream &operator<<(std::ostream &o, DataPLC const &plc);
 	//! the entry name
@@ -334,9 +343,18 @@ std::ostream &operator<<(std::ostream &o, DataPLC const &plc)
 struct State
 {
 	//! constructor
-	State() : m_textZones(), m_bookmarkMap(), m_notesList(), m_notesMap(),
-		m_object(), m_objectMap(), m_tokenMap(), m_tcdMap(),
-		m_objectTypes(), m_plcList(), m_knownPLC()
+	State()
+		: m_textZones()
+		, m_bookmarkMap()
+		, m_notesList()
+		, m_notesMap()
+		, m_object()
+		, m_objectMap()
+		, m_tokenMap()
+		, m_tcdMap()
+		, m_objectTypes()
+		, m_plcList()
+		, m_knownPLC()
 	{
 		initTypeMaps();
 	}
@@ -346,10 +364,8 @@ struct State
 	//! returns the entry corresponding to a type id
 	WPSEntry getTextZones(int id) const
 	{
-		size_t numZones = m_textZones.size();
-		for (size_t i = 0; i < numZones; i++)
+		for (auto const &z : m_textZones)
 		{
-			WPSEntry const &z = m_textZones[i];
 			if (!z.valid()) continue;
 			if (z.id() == id) return z;
 		}
@@ -358,11 +374,10 @@ struct State
 	//! tests if a text zone is simillar to \a entry, if yes, updates is parsed field
 	void setParsed(WPSEntry const &entry, bool fl)
 	{
-		size_t numZones = m_textZones.size();
-		for (size_t i = 0; i < numZones; i++)
+		for (auto const &z : m_textZones)
 		{
-			if (m_textZones[i] != entry) continue;
-			m_textZones[i].setParsed(fl);
+			if (z != entry) continue;
+			z.setParsed(fl);
 			return;
 		}
 	}
@@ -380,7 +395,7 @@ struct State
 			return m_textZones[size_t(strsId)];
 		}
 
-		std::vector<long> const &endPos = m_tcdMap.find(strsId)->second;
+		auto const &endPos = m_tcdMap.find(strsId)->second;
 		if (cellId >= int(endPos.size()))
 			return WPSEntry();
 
@@ -429,30 +444,36 @@ void State::initTypeMaps()
 	{
 		0, 0x1A, 1, 0x22, 2, 0x22, 3, 0x22, 4, 0x22
 	};
-	for (int i = 0; i+1 < int(sizeof(objectTypes)/sizeof(int)); i+=2)
+	for (int i = 0; i+1 < int(WPS_N_ELEMENTS(objectTypes)); i+=2)
 		m_objectTypes[objectTypes[i]] = objectTypes[i+1];
 }
 
 //! Internal: the subdocument of a WPS8Text
-class SubDocument : public WPSTextSubDocument
+class SubDocument final : public WPSTextSubDocument
 {
 public:
 	//! constructor for a note/endnote entry
-	SubDocument(RVNGInputStreamPtr input, WPS8Text &pars, WPSEntry const &entry) :
-		WPSTextSubDocument(input, 0), m_textParser(&pars), m_entry(entry), m_text("") {}
+	SubDocument(RVNGInputStreamPtr const &input, WPS8Text &pars, WPSEntry const &entry)
+		: WPSTextSubDocument(input, nullptr)
+		, m_textParser(&pars)
+		, m_entry(entry)
+		, m_text("") {}
 	//! constructor for a comment entry
-	SubDocument(RVNGInputStreamPtr input, librevenge::RVNGString const &text) :
-		WPSTextSubDocument(input, 0), m_textParser(0), m_entry(), m_text(text) {}
+	SubDocument(RVNGInputStreamPtr const &input, librevenge::RVNGString const &text)
+		: WPSTextSubDocument(input, nullptr)
+		, m_textParser(nullptr)
+		, m_entry()
+		, m_text(text) {}
 
 	//! destructor
-	~SubDocument() {}
+	~SubDocument() final {}
 
 	//! operator==
-	virtual bool operator==(WPSSubDocumentPtr const &doc) const
+	bool operator==(WPSSubDocumentPtr const &doc) const final
 	{
 		if (!WPSSubDocument::operator==(doc))
 			return false;
-		SubDocument const *sDoc = dynamic_cast<SubDocument const *>(doc.get());
+		auto const *sDoc = dynamic_cast<SubDocument const *>(doc.get());
 		if (!sDoc) return false;
 		if (m_entry != sDoc->m_entry) return false;
 		if (m_textParser != sDoc->m_textParser) return false;
@@ -461,14 +482,14 @@ public:
 	}
 
 	//! the parser function
-	void parse(WPSContentListenerPtr &listener, libwps::SubDocumentType type);
+	void parse(WPSContentListenerPtr &listener, libwps::SubDocumentType type) final;
 
 	WPS8Text *m_textParser;
 	WPSEntry m_entry;
 	librevenge::RVNGString m_text;
 private:
-	SubDocument(SubDocument const &orig);
-	SubDocument &operator=(SubDocument const &orig);
+	SubDocument(SubDocument const &) = delete;
+	SubDocument &operator=(SubDocument const &) = delete;
 };
 
 void SubDocument::parse(WPSContentListenerPtr &listener, libwps::SubDocumentType type)
@@ -483,7 +504,7 @@ void SubDocument::parse(WPSContentListenerPtr &listener, libwps::SubDocumentType
 		WPS_DEBUG_MSG(("SubDocument::parse: bad listener\n"));
 		return;
 	}
-	WPSContentListenerPtr &listen =  reinterpret_cast<WPSContentListenerPtr &>(listener);
+	auto &listen =  reinterpret_cast<WPSContentListenerPtr &>(listener);
 
 	if (type==libwps::DOC_COMMENT_ANNOTATION)
 	{
@@ -518,8 +539,11 @@ void SubDocument::parse(WPSContentListenerPtr &listener, libwps::SubDocumentType
 //////////////////////////////////////////////////////////////////////////////
 
 // constructor/destructor
-WPS8Text::WPS8Text(WPS8Parser &parser) : WPSTextParser(parser, parser.getInput()),
-	m_listener(), m_styleParser(), m_state()
+WPS8Text::WPS8Text(WPS8Parser &parser)
+	: WPSTextParser(parser, parser.getInput())
+	, m_listener()
+	, m_styleParser()
+	, m_state()
 {
 	m_state.reset(new WPS8TextInternal::State);
 	m_styleParser.reset(new WPS8TextStyle(*this));
@@ -659,15 +683,15 @@ void WPS8Text::readText(WPSEntry const &entry)
 		int numColumns = mainParser().numColumns();
 		if (m_listener->isSectionOpened())
 			m_listener->closeSection();
-		int w = int(72.0*mainParser().pageWidth()/numColumns);
+		auto w = int(72.0*mainParser().pageWidth()/numColumns);
 		std::vector<int> colSize(size_t(numColumns), w);
 		m_listener->openSection(colSize, librevenge::RVNG_POINT);
 	}
 	int lastCId=-1, lastPId=-1; /* -2: nothing, -1: send default, >= 0: readId */
-	std::vector<DataFOD>::iterator plcIt =	m_FODList.begin();
+	auto plcIt =  m_FODList.begin();
 	while (plcIt != m_FODList.end() && plcIt->m_pos < entry.begin())
 	{
-		DataFOD const &plc = *(plcIt++);
+		auto const &plc = *(plcIt++);
 		if (plc.m_type==DataFOD::ATTR_TEXT)
 			lastCId = plc.m_id;
 		else if (plc.m_type==DataFOD::ATTR_PARAG)
@@ -729,7 +753,7 @@ void WPS8Text::readText(WPSEntry const &entry)
 					WPS_DEBUG_MSG(("WPS8Text::readText: can not find plc %d\n",plc.m_id));
 					break;
 				}
-				WPS8TextInternal::DataPLC const &thePLC = m_state->m_plcList[size_t(plc.m_id)];
+				auto const &thePLC = m_state->m_plcList[size_t(plc.m_id)];
 				f << "[" << thePLC << "]";
 #ifdef DEBUG
 				// no sure, if we want to output this data
@@ -741,7 +765,7 @@ void WPS8Text::readText(WPSEntry const &entry)
 					}
 					else
 					{
-						shared_ptr<WPSSubDocument> doc(new WPS8TextInternal::SubDocument(input, m_state->m_bookmarkMap.find(pos)->second.m_text));
+						std::shared_ptr<WPSSubDocument> doc(new WPS8TextInternal::SubDocument(input, m_state->m_bookmarkMap.find(pos)->second.m_text));
 						m_listener->insertComment(doc);
 					}
 				}
@@ -829,10 +853,10 @@ void WPS8Text::readText(WPSEntry const &entry)
 						WPS_DEBUG_MSG(("WPS8Text::readText can not find notes for position : %lx\n", (unsigned long) fPos));
 						break;
 					}
-					WPS8TextInternal::Notes const &note = *m_state->m_notesMap[fPos];
+					auto const &note = *m_state->m_notesMap[fPos];
 					if (!note.m_corr || note.m_note) break;
 					WPSEntry nEntry = note.getCorrespondanceEntry(fPos);
-					shared_ptr<WPSSubDocument> doc(new WPS8TextInternal::SubDocument(input, *this, nEntry));
+					std::shared_ptr<WPSSubDocument> doc(new WPS8TextInternal::SubDocument(input, *this, nEntry));
 					m_listener->insertNote(special.m_type==WPS8TextStyle::FontData::T_Footnote ? WPSContentListener::FOOTNOTE : WPSContentListener::ENDNOTE, doc);
 					break;
 				}
@@ -880,7 +904,7 @@ void WPS8Text::readText(WPSEntry const &entry)
 					WPS_DEBUG_MSG(("WPSText::readText can not find EOB for position : %lX\n", (unsigned long) objPos));
 					break;
 				}
-				WPS8TextInternal::Object const &obj = m_state->m_objectMap.find(objPos)->second;
+				auto const &obj = m_state->m_objectMap.find(objPos)->second;
 				if (obj.m_type == WPS8TextInternal::Object::Image)
 					mainParser().sendObject(obj.m_size, obj.m_id, true);
 				else if (obj.m_type == WPS8TextInternal::Object::Table)
@@ -913,9 +937,8 @@ void WPS8Text::readText(WPSEntry const &entry)
 void WPS8Text::flushExtra()
 {
 	if (!m_listener) return;
-	for (size_t i = 0; i < m_state->m_textZones.size(); i++)
+	for (auto const &zone : m_state->m_textZones)
 	{
-		WPSEntry const &zone = m_state->m_textZones[i];
 		if (!zone.valid() || zone.id() == 2 || zone.id() ==3
 		        || zone.isParsed())
 			continue;
@@ -928,10 +951,9 @@ void WPS8Text::flushExtra()
  */
 bool WPS8Text::readStructures()
 {
-	WPS8Parser::NameMultiMap &nameTable = getNameEntryMap();
-	WPS8Parser::NameMultiMap::iterator pos;
+	auto &nameTable = getNameEntryMap();
 	/* What is the total length of the text? */
-	pos = nameTable.lower_bound("TEXT");
+	auto pos = nameTable.lower_bound("TEXT");
 	if (nameTable.end() == pos)
 	{
 		WPS_DEBUG_MSG(("Works: error: no TEXT in header index table\n"));
@@ -1145,8 +1167,8 @@ bool WPS8Text::readNotes(WPSEntry const &entry)
 	long endPos = entry.end();
 	input->seek(debPos, librevenge::RVNG_SEEK_SET);
 
-	long zone = (long) libwps::readU32(input);
-	int numTZones = int(m_state->m_textZones.size());
+	auto zone = (long) libwps::readU32(input);
+	auto numTZones = int(m_state->m_textZones.size());
 	if (zone < 0 || zone >= numTZones)
 	{
 		WPS_DEBUG_MSG(("WPS8Text::readNotes: warning: readNotes unknown zone: %d, numZones = %d\n", int(zone), numTZones));
@@ -1154,7 +1176,7 @@ bool WPS8Text::readNotes(WPSEntry const &entry)
 	}
 
 	// CHECK ME, it is the number of notes or only an unknow field
-	int nNotes = (int) libwps::read32(input);
+	auto nNotes = (int) libwps::read32(input);
 	if (nNotes < 0 || 16+4*(3*long(nNotes)+1) > length)
 	{
 		WPS_DEBUG_MSG(("WPS8Text::readNotes: warning: readNotes number=%d\n", nNotes));
@@ -1188,7 +1210,7 @@ bool WPS8Text::readNotes(WPSEntry const &entry)
 	{
 		WPS_DEBUG_MSG(("WPS8Text::readNotes: unknown entry id = %d\n", int(entry.id())));
 	}
-	std::vector<long> &notesPos = notes.m_positions;
+	auto &notesPos = notes.m_positions;
 	for (int i = 0; i <= nNotes; i++)
 	{
 		long ptr = begTPos + 2*(long) libwps::read32(input);
@@ -1208,7 +1230,7 @@ bool WPS8Text::readNotes(WPSEntry const &entry)
 		pos = input->tell();
 		f.str("");
 		f << entry.name() << i << ":";
-		int type = (int) libwps::read16(input);
+		auto type = (int) libwps::read16(input);
 		switch (type)
 		{
 		case 0:
@@ -1222,7 +1244,7 @@ bool WPS8Text::readNotes(WPSEntry const &entry)
 			break;
 		}
 		f << "id=" << libwps::read16(input) << ",";
-		long val = (long) libwps::read32(input);
+		auto val = (long) libwps::read32(input);
 		if (val != -1) f << "label" << val << ",";
 		ascii().addPos(pos);
 		ascii().addNote(f.str().c_str());
@@ -1258,33 +1280,29 @@ bool WPS8Text::readNotes(WPSEntry const &entry)
 void WPS8Text::createNotesCorrespondance()
 {
 	using WPS8TextInternal::Notes;
-	std::vector<Notes> &notesList = m_state->m_notesList;
-	size_t numNotes = notesList.size();
-	if (!numNotes) return;
+	auto &notesList = m_state->m_notesList;
+	if (notesList.empty()) return;
 
 	// a map to store notes and their correspondance
 	std::map<Notes const *, int, Notes::Compare> nMap;
-	std::map<Notes const *, int, Notes::Compare>::iterator nIt, nIt2;
+	auto &notesMap = m_state->m_notesMap;
 
-	std::map<long, Notes *> &notesMap = m_state->m_notesMap;
-
-	for (size_t i = 0; i < numNotes; i++)
+	for (auto const &note : notesList)
 	{
 		int nSameNote = 0;
-		if ((nIt = nMap.find(&notesList[i])) != nMap.end())
+		auto nIt = nMap.find(&note);
+		if (nIt != nMap.end())
 		{
 			WPS_DEBUG_MSG(("WPS8Text::createNotesCorrespondance: find some dupplicated notes\n"));
 			nSameNote = nIt->second+1;
 		}
-		nMap[&(notesList[i])] = nSameNote;
+		nMap[&note] = nSameNote;
 	}
 
-	nIt = nMap.begin();
-
-	while (nIt != nMap.end())
+	for (auto it : nMap)
 	{
-		Notes &notes = const_cast<Notes &>(*nIt->first);
-		if (nIt++->second != 0)
+		auto &notes = const_cast<Notes &>(*it.first);
+		if (it.second != 0)
 			continue;
 
 		WPSEntry entry = getEntry(notes.m_zoneCorr);
@@ -1304,7 +1322,7 @@ void WPS8Text::createNotesCorrespondance()
 		correspondingNotes.m_type = notes.m_type;
 		correspondingNotes.m_zoneNote = notes.m_zoneCorr;
 		correspondingNotes.m_zoneCorr = notes.m_zoneNote;
-		nIt2 = nMap.find(&correspondingNotes);
+		auto nIt2 = nMap.find(&correspondingNotes);
 		if (nIt2 == nMap.end())
 		{
 			WPS_DEBUG_MSG(("WPS8Text::createNotesCorrespondance: can not find the corresponding note\n"));
@@ -1318,7 +1336,7 @@ void WPS8Text::createNotesCorrespondance()
 		}
 
 		if (nIt2->second != 0) continue; // a duplicated notes
-		Notes &notesCor = const_cast<Notes &>(*nIt2->first);
+		auto &notesCor = const_cast<Notes &>(*nIt2->first);
 		notes.m_corr = &notesCor;
 		notes.m_note = false;
 		notesCor.m_corr = &notes;
@@ -1351,11 +1369,10 @@ bool WPS8Text::defDataParser
 		return true;
 	}
 
-	size_t numChild = data.m_recursData.size();
-	if (numChild == 0) return true;
+	if (data.m_recursData.empty()) return true;
 
 	f << "{";
-	for (size_t c = 0; c < numChild; c++) f << data.m_recursData[c] << ",";
+	for (auto const &dt : data.m_recursData) f << dt << ",";
 	f << "}";
 
 	mess = f.str();
@@ -1372,7 +1389,7 @@ bool WPS8Text::textZonesDataParser
 	if (bot < m_textPositions.begin() || eot > m_textPositions.end()) return false;
 
 	libwps::DebugStream f;
-	if (!data.isRead() && !data.readArrayBlock() && data.m_recursData.size() == 0)
+	if (!data.isRead() && !data.readArrayBlock() && data.m_recursData.empty())
 	{
 		f << ", " << data;
 		mess = f.str();
@@ -1380,14 +1397,11 @@ bool WPS8Text::textZonesDataParser
 		return false;
 	}
 
-	size_t numChild = data.m_recursData.size();
-
 	bool idSet = false;
 	int id = -1;
 
-	for (size_t c = 0; c < numChild; c++)
+	for (auto const &dt : data.m_recursData)
 	{
-		WPS8Struct::FileData const &dt = data.m_recursData[c];
 		if (dt.isBad()) continue;
 		if (dt.id()!=0 || dt.type() != 0x22)
 		{
@@ -1453,7 +1467,7 @@ bool WPS8Text::bmktEndDataParser(long endPage, std::vector<long> const &textPtrs
 		pos = input->tell();
 		if (input->tell() + 4 > endPage) return false;
 
-		int id = (int) libwps::read32(input);
+		auto id = (int) libwps::read32(input);
 		f << id << ",";
 		if (id < 0 || (id > numBmkt && id > 100))
 		{
@@ -1466,7 +1480,7 @@ bool WPS8Text::bmktEndDataParser(long endPage, std::vector<long> const &textPtrs
 	}
 	f << ")";
 
-	int sz1 = (int) libwps::readU32(input);
+	auto sz1 = (int) libwps::readU32(input);
 	pos = input->tell();
 	if (sz1 < 4*numBmkt || pos+1+sz1 > endPage)
 	{
@@ -1527,7 +1541,7 @@ bool WPS8Text::bmktEndDataParser(long endPage, std::vector<long> const &textPtrs
 		{
 			input->seek(pos, librevenge::RVNG_SEEK_SET);
 			librevenge::RVNGString val;
-			int sz = (int) libwps::readU16(input);
+			auto sz = (int) libwps::readU16(input);
 			if (pos + 2+ 2*sz > endPage || !readString(input, 2*sz, val))
 			{
 				WPS_DEBUG_MSG(("WPS8Text::bmktEndDataParser: pb with %dth string size=%d\n", int(i), sz));
@@ -1551,7 +1565,7 @@ bool WPS8Text::bmktEndDataParser(long endPage, std::vector<long> const &textPtrs
 			continue;
 		}
 		else m_state->m_bookmarkMap[textPtrs[t]] = listBmk[t];
-		int newId = int(m_state->m_plcList.size());
+		auto newId = int(m_state->m_plcList.size());
 
 		WPS8TextInternal::DataPLC plc;
 		plc.m_type = WPS8TextInternal::BMKT;
@@ -1593,14 +1607,12 @@ bool WPS8Text::objectDataParser(long bot, long /*eot*/, int /*id*/,
 	obj.m_error="";
 
 	mess = "";
-	size_t numChild = data.m_recursData.size();
 
 	long val[5] = { 0, 0, 0, 0, 0 };
 	bool setVal[5] = { false, false, false, false, false };
 	libwps::DebugStream f;
-	for (size_t c = 0; c < numChild; c++)
+	for (auto const &dt : data.m_recursData)
 	{
-		WPS8Struct::FileData const &dt = data.m_recursData[c];
 		if (dt.isBad()) continue;
 		if (m_state->m_objectTypes.find(dt.id())==m_state->m_objectTypes.end())
 		{
@@ -1668,7 +1680,7 @@ bool WPS8Text::tokenEndDataParser(long endPage, std::vector<long> const &textPtr
 		long pos = input->tell();
 		if (input->tell() + 2 > endPage) return false;
 
-		int sz = (int) libwps::read16(input);
+		auto sz = (int) libwps::read16(input);
 		if (sz < 2 || pos+sz > endPage)
 		{
 			input->seek(pos, librevenge::RVNG_SEEK_SET);
@@ -1683,12 +1695,10 @@ bool WPS8Text::tokenEndDataParser(long endPage, std::vector<long> const &textPtr
 			return false;
 		}
 
-		size_t numChild = data.m_recursData.size();
 		tokn.m_error ="";
 		f.str("");
-		for (size_t c = 0; c < numChild; c++)
+		for (auto const &dt : data.m_recursData)
 		{
-			WPS8Struct::FileData const &dt = data.m_recursData[c];
 			if (dt.isBad()) continue;
 			if (dt.id()<0 || dt.id()>2 || dt.type()!=0x22)
 			{
@@ -1748,7 +1758,7 @@ bool WPS8Text::tokenEndDataParser(long endPage, std::vector<long> const &textPtr
 		if (input->tell() + 2 > endPage) return false;
 
 		WPS8Struct::FileData data;
-		int sz = (int) libwps::read16(input);
+		auto sz = (int) libwps::read16(input);
 		if (sz < 2 || pos+sz > endPage)
 		{
 			input->seek(pos, librevenge::RVNG_SEEK_SET);
@@ -1767,10 +1777,8 @@ bool WPS8Text::tokenEndDataParser(long endPage, std::vector<long> const &textPtr
 
 		bool idSet = false;
 		int id = -1;
-		size_t numChild = data.m_recursData.size();;
-		for (size_t c = 0; c < numChild; c++)
+		for (auto const &dt : data.m_recursData)
 		{
-			WPS8Struct::FileData const &dt = data.m_recursData[c];
 			if (dt.isBad()) continue;
 			if (dt.id() != 0 || dt.type()!=0x22)
 			{
@@ -1805,17 +1813,17 @@ bool WPS8Text::tokenEndDataParser(long endPage, std::vector<long> const &textPtr
 		if (pos+20 > endPage) return false;
 		f.str("");
 		f << "TOKN(strings):";
-		long unkn = (long) libwps::read32(input);
+		auto unkn = (long) libwps::read32(input);
 		if (unkn+20+pos != endPage)
 			f << "unkn=" << std::hex << unkn+20+pos << std::dec << ",";
-		int N = (int) libwps::read32(input);
+		auto N = (int) libwps::read32(input);
 		if (N != numFollow) f << "###";
 		f << "N=" << N << ",";
 		// 8760a4 | b37464 | 6092ea37 | 6105db0e | ffffffff
 		f << std::hex << libwps::readU32(input) << std::dec << ",";
 		for (int i = 0; i <2; i++)
 		{
-			int val = (int) libwps::read32(input);
+			auto val = (int) libwps::read32(input);
 			if (val) f << "###f" << i << "=" << val << ",";
 		}
 		f << "ptr=(";
@@ -1828,7 +1836,7 @@ bool WPS8Text::tokenEndDataParser(long endPage, std::vector<long> const &textPtr
 
 		for (int i = 0; i < N; i++)
 		{
-			long val = (long) libwps::read32(input);
+			auto val = (long) libwps::read32(input);
 			if (val < 4*N)
 			{
 				input->seek(pos, librevenge::RVNG_SEEK_SET);
@@ -1854,7 +1862,7 @@ bool WPS8Text::tokenEndDataParser(long endPage, std::vector<long> const &textPtr
 	{
 		long pos = sPtrs[i];
 		input->seek(pos, librevenge::RVNG_SEEK_SET);
-		int sz = (int) libwps::read16(input);
+		auto sz = (int) libwps::read16(input);
 		if (sz < 0 || pos+2*sz+2 > endPage) return false;
 		librevenge::RVNGString str;
 		readString(input, 2*sz, str);
@@ -1883,7 +1891,7 @@ bool WPS8Text::tokenEndDataParser(long endPage, std::vector<long> const &textPtr
 			continue;
 		}
 		else m_state->m_tokenMap[textPtrs[t]] = listToken[t];
-		int newId = int(m_state->m_plcList.size());
+		auto newId = int(m_state->m_plcList.size());
 
 		WPS8TextInternal::DataPLC plc;
 		plc.m_type = WPS8TextInternal::TOKEN;
@@ -1937,8 +1945,10 @@ struct PLC
 	typedef enum { T_CST=0, T_STRUCT,  T_COMPLEX, T_UNKNOWN} Type;
 
 	//! constructor
-	PLC(PLCType w= WPS8TextInternal::Unknown, Position p=P_UNKNOWN, Type t=T_UNKNOWN) :
-		m_type(w), m_pos(p), m_contentType(t) {}
+	PLC(PLCType w= WPS8TextInternal::Unknown, Position p=P_UNKNOWN, Type t=T_UNKNOWN)
+		: m_type(w)
+		, m_pos(p)
+		, m_contentType(t) {}
 
 	//! PLC type
 	PLCType m_type;
@@ -1959,7 +1969,7 @@ KnownPLC::~KnownPLC()
 
 PLC KnownPLC::get(std::string const &name)
 {
-	std::map<std::string, PLC>::iterator pos = m_knowns.find(name);
+	auto pos = m_knowns.find(name);
 	if (pos == m_knowns.end()) return PLC();
 	return pos->second;
 }
@@ -2003,7 +2013,7 @@ bool WPS8Text::readPLC
 	unsigned dataSz = libwps::readU32(input);
 	libwps::DebugStream f;
 	f << "PLC: N=" << nPLC << ", dSize=" << dataSz;
-	WPS8PLCInternal::PLC plcType = m_state->m_knownPLC.get(entry.name());
+	auto plcType = m_state->m_knownPLC.get(entry.name());
 
 	if (plcType.m_contentType == WPS8PLCInternal::PLC::T_UNKNOWN && long(4ul*nPLC+16 + dataSz *nPLC) == length)
 		plcType.m_contentType = WPS8PLCInternal::PLC::T_CST;
@@ -2054,7 +2064,7 @@ bool WPS8Text::readPLC
 	f << ",pos = (";
 	for (unsigned i = 0; i <= nPLC; i++)
 	{
-		long pos = (long) libwps::readU32(input);
+		auto pos = (long) libwps::readU32(input);
 		switch (plcType.m_pos)
 		{
 		case WPS8PLCInternal::PLC::P_ABS:
@@ -2134,7 +2144,7 @@ bool WPS8Text::readPLC
 		}
 		case WPS8PLCInternal::PLC::T_STRUCT :
 		{
-			long sz = (long) libwps::read16(input);
+			auto sz = (long) libwps::read16(input);
 			if (sz < 2 || sz+pos > endPage)
 			{
 				ok = false;
@@ -2172,7 +2182,7 @@ bool WPS8Text::readPLC
 			break;
 		}
 
-		const int plcID = (int) m_state->m_plcList.size();
+		const auto plcID = (int) m_state->m_plcList.size();
 		if (i < fods.size())
 		{
 			fods[i].m_id = plcID;
