@@ -45,7 +45,9 @@ namespace WPS8TextStyleInternal
 struct Font : public WPSFont
 {
 	//! constructor
-	Font() : WPSFont(), m_special() { }
+	Font()
+		: WPSFont()
+		, m_special() { }
 	static Font def()
 	{
 		Font res;
@@ -85,9 +87,14 @@ std::ostream &operator<<(std::ostream &o, Font const &ft)
 struct State
 {
 	//! constructor
-	State() : m_fontNames(), m_defaultFont(Font::def()), m_fontList(),
-		m_defaultParagraph(), m_paragraphList(),
-		m_fontTypes(), m_paragraphTypes()
+	State()
+		: m_fontNames()
+		, m_defaultFont(Font::def())
+		, m_fontList()
+		, m_defaultParagraph()
+		, m_paragraphList()
+		, m_fontTypes()
+		, m_paragraphTypes()
 	{
 		initTypeMaps();
 	}
@@ -124,7 +131,7 @@ void State::initTypeMaps()
 		0x22, 0x22, 0x23, 0x22, 0x24, 0x8A,
 		0x2d, 0x2, 0x2e, 0x22,
 	};
-	for (int i = 0; i+1 < int(sizeof(fontTypes)/sizeof(int)); i+=2)
+	for (int i = 0; i+1 < int(WPS_N_ELEMENTS(fontTypes)); i+=2)
 		m_fontTypes[fontTypes[i]] = fontTypes[i+1];
 	static int const paragraphTypes[] =
 	{
@@ -136,7 +143,7 @@ void State::initTypeMaps()
 		0x2a, 0x12,
 		0x31, 0x12, 0x32, 0x82, 0x33, 0x12, 0x34, 0x22
 	};
-	for (int i = 0; i+1 < int(sizeof(paragraphTypes)/sizeof(int)); i+=2)
+	for (int i = 0; i+1 < int(WPS_N_ELEMENTS(paragraphTypes)); i+=2)
 		m_paragraphTypes[paragraphTypes[i]] = paragraphTypes[i+1];
 }
 }
@@ -144,9 +151,12 @@ void State::initTypeMaps()
 ////////////////////////////////////////////////////////////
 // constructor destructor
 ////////////////////////////////////////////////////////////
-WPS8TextStyle::WPS8TextStyle(WPS8Text &parser) :
-	m_mainParser(parser), m_input(parser.getInput()), m_listener(),
-	m_state(), m_asciiFile(parser.ascii())
+WPS8TextStyle::WPS8TextStyle(WPS8Text &parser)
+	: m_mainParser(parser)
+	, m_input(parser.getInput())
+	, m_listener()
+	, m_state()
+	, m_asciiFile(parser.ascii())
 {
 	m_state.reset(new WPS8TextStyleInternal::State);
 }
@@ -160,11 +170,10 @@ WPS8TextStyle::~WPS8TextStyle()
 ////////////////////////////////////////////////////////////
 bool WPS8TextStyle::readStructures()
 {
-	WPS8Parser::NameMultiMap &nameTable = m_mainParser.getNameEntryMap();
-	WPS8Parser::NameMultiMap::iterator pos;
+	auto &nameTable = m_mainParser.getNameEntryMap();
 
 	/* read fonts table */
-	pos = nameTable.find("FONT");
+	auto pos = nameTable.find("FONT");
 	if (nameTable.end() == pos)
 	{
 		WPS_DEBUG_MSG(("WPS8TextStyle::parse: error: no FONT in header index table\n"));
@@ -179,12 +188,11 @@ bool WPS8TextStyle::readStructures()
 		if (!findFDPStructures(st, zones))
 			findFDPStructuresByHand(st, zones);
 
-		size_t numZones = zones.size();
 		std::vector<WPS8Text::DataFOD> fdps;
 		WPS8Text::FDPParser parser = st==0  ? (WPS8Text::FDPParser) &WPS8Text::readParagraph
 		                             : (WPS8Text::FDPParser) &WPS8Text::readFont;
-		for (size_t i = 0; i < numZones; i++)
-			m_mainParser.readFDP(zones[i], fdps, parser);
+		for (auto const &z : zones)
+			m_mainParser.readFDP(z, fdps, parser);
 		m_mainParser.m_FODList = m_mainParser.mergeSortedFODLists(m_mainParser.m_FODList, fdps);
 	}
 	// read SGP zone
@@ -222,8 +230,8 @@ bool WPS8TextStyle::readFontNames(WPSEntry const &entry)
 	long debPos = entry.begin();
 	m_input->seek(debPos, librevenge::RVNG_SEEK_SET);
 
-	long len = (long) libwps::readU32(m_input); // len + 0x14 = size
-	size_t n_fonts = (size_t) libwps::readU32(m_input);
+	auto len = (long) libwps::readU32(m_input); // len + 0x14 = size
+	auto n_fonts = (size_t) libwps::readU32(m_input);
 
 	if (long(4*n_fonts) > len)
 	{
@@ -258,7 +266,7 @@ bool WPS8TextStyle::readFontNames(WPSEntry const &entry)
 		debPos = m_input->tell();
 		if (debPos+6 > long(pageEnd)) break;
 
-		int string_size = (int) libwps::readU16(m_input);
+		auto string_size = (int) libwps::readU16(m_input);
 		if (debPos+2*string_size+6 > long(pageEnd)) break;
 
 		librevenge::RVNGString s;
@@ -319,10 +327,8 @@ bool WPS8TextStyle::readSGP(WPSEntry const &entry)
 	WPS8Struct::FileData mainData;
 	std::string error;
 	bool readOk=readBlockData(m_input, endPage,mainData, error);
-	size_t numChild = mainData.m_recursData.size();
-	for (size_t c = 0; c < numChild; c++)
+	for (auto const &dt : mainData.m_recursData)
 	{
-		WPS8Struct::FileData const &dt = mainData.m_recursData[c];
 		if (dt.isBad()) continue;
 		if (dt.id() == 0)
 			f << "tabSep[default]=" <<  float(dt.m_value)/914400.f << "(inches),";
@@ -343,7 +349,7 @@ bool WPS8TextStyle::readSGP(WPSEntry const &entry)
 ////////////////////////////////////////////////////////////
 bool WPS8TextStyle::readFont(long endPos, int &id, std::string &mess)
 {
-	WPS8TextStyleInternal::Font font=WPS8TextStyleInternal::Font::def();
+	auto font=WPS8TextStyleInternal::Font::def();
 
 	long actPos = m_input->tell();
 	long size = endPos - actPos;
@@ -368,11 +374,9 @@ bool WPS8TextStyle::readFont(long endPos, int &id, std::string &mess)
 	libwps::DebugStream f;
 	if (mainData.m_value) f << "unk=" << mainData.m_value << ",";
 
-	size_t numChild = mainData.m_recursData.size();
 	uint32_t textAttributeBits = 0;
-	for (size_t c = 0; c < numChild; c++)
+	for (auto const &data : mainData.m_recursData)
 	{
-		WPS8Struct::FileData const &data = mainData.m_recursData[c];
 		if (data.isBad()) continue;
 		if (m_state->m_fontTypes.find(data.id())==m_state->m_fontTypes.end())
 		{
@@ -545,14 +549,13 @@ bool WPS8TextStyle::readFont(long endPos, int &id, std::string &mess)
 				break;
 			}
 
-			size_t nChild = data.m_recursData.size();
-			if (!nChild || data.m_recursData[0].isBad() || data.m_recursData[0].type() != 0x18)
+			if (data.m_recursData.empty() || data.m_recursData[0].isBad() || data.m_recursData[0].type() != 0x18)
 			{
 				WPS_DEBUG_MSG(("WPS8TextStyle::readFont: can not read font id\n"));
 				f << "###f24=[" << data << "]";
 				break;
 			}
-			uint8_t fontId = (uint8_t)data.m_recursData[0].m_value;
+			auto fontId = (uint8_t)data.m_recursData[0].m_value;
 			if (fontId < m_state->m_fontNames.size())
 
 				font.m_name = m_state->m_fontNames[fontId];
@@ -561,9 +564,8 @@ bool WPS8TextStyle::readFont(long endPos, int &id, std::string &mess)
 				WPS_DEBUG_MSG(("WPS8TextStyle::readFont: can not read find font %d\n", int(fontId)));
 			}
 			std::vector<int> formats;
-			for (size_t i = 0; i < nChild; i++)
+			for (auto const &subD : data.m_recursData)
 			{
-				WPS8Struct::FileData const &subD = data.m_recursData[i];
 				if (subD.isBad()) continue;
 				int formId = subD.id() >> 3;
 				int sId = subD.id() & 0x7;
@@ -573,7 +575,7 @@ bool WPS8TextStyle::readFont(long endPos, int &id, std::string &mess)
 					formats[size_t(formId)] = int(subD.m_value);
 				}
 				else
-					f << "###formats"<<formId<<"." << sId << "=" << data.m_recursData[i] << ",";
+					f << "###formats"<<formId<<"." << sId << "=" << subD << ",";
 			}
 			// CHECKME: list of font ids ....
 			f << "formats=[" << std::hex;
@@ -615,8 +617,7 @@ void WPS8TextStyle::sendFont(int fId, WPS8TextStyle::FontData &data)
 		WPS_DEBUG_MSG(("WPS8TextStyle::sendFont: can not find font id %d\n", fId));
 		return;
 	}
-	WPS8TextStyleInternal::Font const &font =
-	    fId < 0 ? m_state->m_defaultFont : m_state->m_fontList[size_t(fId)];
+	auto const &font = fId < 0 ? m_state->m_defaultFont : m_state->m_fontList[size_t(fId)];
 	data = font.special();
 	if (m_listener)
 		m_listener->setFont(font);
@@ -646,9 +647,8 @@ bool WPS8TextStyle::readParagraph(long endPos, int &id, std::string &mess)
 
 	WPSParagraph para;
 	WPSColor paraColor[] = { WPSColor::black(), WPSColor::white() };
-	for (size_t c = 0; c < mainData.m_recursData.size(); c++)
+	for (auto const &data : mainData.m_recursData)
 	{
-		WPS8Struct::FileData const &data = mainData.m_recursData[c];
 		if (data.isBad()) continue;
 		if (m_state->m_paragraphTypes.find(data.id())==m_state->m_paragraphTypes.end())
 		{
@@ -728,7 +728,7 @@ bool WPS8TextStyle::readParagraph(long endPos, int &id, std::string &mess)
 			// link to bullet or numbering
 
 			// first check if this can be a numbering level
-			int suffixId = int(data.m_value >> 16); // 0 -> . 2->) 3-> ??
+			auto suffixId = int(data.m_value >> 16); // 0 -> . 2->) 3-> ??
 			int type = data.m_value & 0xFFFF;
 
 			if (data.m_value && suffixId >= 0 && suffixId < 5 && type >= 0 && type <= 6)
@@ -888,7 +888,7 @@ bool WPS8TextStyle::readParagraph(long endPos, int &id, std::string &mess)
 			}
 			if (nChild == 1) break;
 
-			int numTabs = int(data.m_recursData[0].m_value);
+			auto numTabs = int(data.m_recursData[0].m_value);
 			if (numTabs == 0 || nChild < 2 ||
 			        data.m_recursData[1].isBad() || data.m_recursData[1].id() != 0x28)
 			{
@@ -903,14 +903,13 @@ bool WPS8TextStyle::readParagraph(long endPos, int &id, std::string &mess)
 			        (mData.isRead() || mData.readArrayBlock() || mData.m_recursData.size() != 0))
 			{
 				lastParsed = 1;
-				size_t nTabsChilds = mData.m_recursData.size();
 				int actTab = 0;
 				para.m_tabs.resize(size_t(numTabs));
 
-				for (size_t i = 0; i < nTabsChilds; i++)
+				for (auto const &mDataC : mData.m_recursData)
 				{
-					if (mData.m_recursData[i].isBad()) continue;
-					int value = mData.m_recursData[i].id();
+					if (mDataC.isBad()) continue;
+					int value = mDataC.id();
 					int wTab = value/8;
 					int what = value%8;
 
@@ -924,18 +923,18 @@ bool WPS8TextStyle::readParagraph(long endPos, int &id, std::string &mess)
 						actTab++;
 					}
 
-					if (mData.m_recursData[i].isNumber() && wTab==actTab && what == 0
+					if (mDataC.isNumber() && wTab==actTab && what == 0
 					        && actTab < numTabs)
 					{
 						para.m_tabs[size_t(actTab)].m_alignment = WPSTabStop::LEFT;
-						para.m_tabs[size_t(actTab)].m_position =  float(mData.m_recursData[i].m_value)/914400.f;
+						para.m_tabs[size_t(actTab)].m_position =  float(mDataC.m_value)/914400.f;
 
 						actTab++;
 						continue;
 					}
-					if (mData.m_recursData[i].isNumber() && wTab == actTab-1 && what == 1)
+					if (mDataC.isNumber() && wTab == actTab-1 && what == 1)
 					{
-						int actVal = int(mData.m_recursData[i].m_value);
+						auto actVal = int(mDataC.m_value);
 						switch ((actVal & 0x3))
 						{
 						case 0:
@@ -983,12 +982,12 @@ bool WPS8TextStyle::readParagraph(long endPos, int &id, std::string &mess)
 						}
 						continue;
 					}
-					if (mData.m_recursData[i].isNumber() && wTab == actTab-1 && what == 2)
+					if (mDataC.isNumber() && wTab == actTab-1 && what == 2)
 					{
-						para.m_tabs[size_t(actTab-1)].m_leaderCharacter = (uint16_t) mData.m_recursData[i].m_value;
+						para.m_tabs[size_t(actTab-1)].m_leaderCharacter = (uint16_t) mDataC.m_value;
 						continue;
 					}
-					f << "###tabData:fl" << actTab << "=" << mData.m_recursData[i] << ",";
+					f << "###tabData:fl" << actTab << "=" << mDataC << ",";
 				}
 				if (actTab != numTabs)
 				{
@@ -1052,8 +1051,7 @@ void WPS8TextStyle::sendParagraph(int pId)
 		return;
 	}
 	if (!m_listener) return;
-	WPSParagraph const &para=
-	    pId < 0 ? m_state->m_defaultParagraph : m_state->m_paragraphList[size_t(pId)];
+	auto const &para=pId < 0 ? m_state->m_defaultParagraph : m_state->m_paragraphList[size_t(pId)];
 	m_listener->setParagraph(para);
 }
 
@@ -1140,7 +1138,7 @@ bool WPS8TextStyle::readSTSH(WPSEntry const &entry)
 		f << "):";
 
 		m_input->seek(pos, librevenge::RVNG_SEEK_SET);
-		int size = (int) libwps::readU16(m_input);
+		auto size = (int) libwps::readU16(m_input);
 		bool correct = true;
 		if (2*size + 2 + type != length) correct = false;
 		else
@@ -1159,7 +1157,7 @@ bool WPS8TextStyle::readSTSH(WPSEntry const &entry)
 			case 0:
 			{
 				WPS8Struct::FileData mainData;
-				int dataSz = (int) libwps::readU16(m_input);
+				auto dataSz = (int) libwps::readU16(m_input);
 				if (dataSz+2 != 2*size)
 				{
 					correct = false;
@@ -1208,8 +1206,7 @@ bool WPS8TextStyle::findFDPStructures(int which, std::vector<WPSEntry> &zones)
 	char const *indexName = which ? "BTEC" : "BTEP";
 	char const *sIndexName = which ? "FDPC" : "FDPP";
 
-	WPS8Parser::NameMultiMap::iterator pos =
-	    m_mainParser.getNameEntryMap().lower_bound(indexName);
+	auto pos = m_mainParser.getNameEntryMap().lower_bound(indexName);
 
 	std::vector<WPSEntry const *> listIndexed;
 	while (pos != m_mainParser.getNameEntryMap().end())
@@ -1257,18 +1254,15 @@ bool WPS8TextStyle::findFDPStructures(int which, std::vector<WPSEntry> &zones)
 	for (size_t i = 0; i < nFind; i++)
 	{
 		WPSEntry const &entry = *(listIndexed[i]);
-
 		std::vector<long> textPtrs;
 		std::vector<long> listValues;
 
 		if (!m_mainParser.readPLC(entry, textPtrs, listValues)) return false;
 
-		size_t numV = listValues.size();
-		if (textPtrs.size() != numV+1) return false;
+		if (textPtrs.size() != listValues.size()+1) return false;
 
-		for (size_t j = 0; j < numV; j++)
+		for (auto position : listValues)
 		{
-			long position = listValues[j];
 			if (position <= 0) return false;
 
 			offsIt = offsetMap.find(position);
@@ -1288,8 +1282,7 @@ bool WPS8TextStyle::findFDPStructuresByHand(int which, std::vector<WPSEntry> &zo
 	WPS_DEBUG_MSG(("WPS8TextStyle::findFDPStructuresByHand: error: need to create %s list by hand \n", indexName));
 	zones.resize(0);
 
-	WPS8Parser::NameMultiMap::iterator pos =
-	    m_mainParser.getNameEntryMap().lower_bound(indexName);
+	auto pos = m_mainParser.getNameEntryMap().lower_bound(indexName);
 	while (pos != m_mainParser.getNameEntryMap().end())
 	{
 		WPSEntry const &entry = pos++->second;
