@@ -64,12 +64,14 @@ bool WPSCellFormat::convertDTFormat(std::string const &dtFormat, librevenge::RVN
 		{
 		case 'Y':
 			list.insert("number:style", "long");
+			WPS_FALLTHROUGH;
 		case 'y':
 			list.insert("librevenge:value-type", "year");
 			propVect.append(list);
 			break;
 		case 'B':
 			list.insert("number:style", "long");
+			WPS_FALLTHROUGH;
 		case 'b':
 		case 'h':
 			list.insert("librevenge:value-type", "month");
@@ -82,13 +84,14 @@ bool WPSCellFormat::convertDTFormat(std::string const &dtFormat, librevenge::RVN
 			break;
 		case 'e':
 			list.insert("number:style", "long");
-		// fall-through intended
+			WPS_FALLTHROUGH;
 		case 'd':
 			list.insert("librevenge:value-type", "day");
 			propVect.append(list);
 			break;
 		case 'A':
 			list.insert("number:style", "long");
+			WPS_FALLTHROUGH;
 		case 'a':
 			list.insert("librevenge:value-type", "day-of-week");
 			propVect.append(list);
@@ -96,7 +99,7 @@ bool WPSCellFormat::convertDTFormat(std::string const &dtFormat, librevenge::RVN
 
 		case 'H':
 			list.insert("number:style", "long");
-		// fall-through intended
+			WPS_FALLTHROUGH;
 		case 'I':
 			list.insert("librevenge:value-type", "hours");
 			propVect.append(list);
@@ -189,8 +192,23 @@ void WPSCellFormat::addTo(librevenge::RVNGPropertyList &propList) const
 	case VALIGN_DEFAULT:
 		break; // default
 	default:
-		WPS_DEBUG_MSG(("MWAWCell::addTo: called with unknown valign=%d\n", vAlignement()));
+		WPS_DEBUG_MSG(("WPSCell::addTo: called with unknown valign=%d\n", vAlignement()));
 	}
+	switch (wrapping())
+	{
+	case WRAP_WRAP:
+		propList.insert("fo:wrap-option", "wrap");
+		break;
+	case WRAP_NO_WRAP:
+		propList.insert("fo:wrap-option", "no-wrap");
+		break;
+	case WRAP_DEFAULT:
+		break;
+	default:
+		WPS_DEBUG_MSG(("WPSCell::addTo: called with unknown wrapping=%d\n", wrapping()));
+	}
+	if (m_rotation)
+		propList.insert("style:rotation-angle",m_rotation);
 
 	for (size_t c = 0; c < m_bordersList.size(); c++)
 	{
@@ -218,6 +236,7 @@ void WPSCellFormat::addTo(librevenge::RVNGPropertyList &propList) const
 		propList.insert("fo:background-color", backgroundColor().str().c_str());
 	if (m_protected)
 		propList.insert("style:cell-protect","protected");
+	propList.insert("fo:padding",0,librevenge::RVNG_POINT); // changme
 }
 
 std::string WPSCellFormat::getValueType() const
@@ -270,11 +289,11 @@ bool WPSCellFormat::getNumberingProperties(librevenge::RVNGPropertyList &propLis
 		{
 		case 5: // thousand
 			propList.insert("number:grouping", true);
-		// fall-through intended
+			WPS_FALLTHROUGH;
 		case 0: // default
 			if (m_subFormat==0)
 				propList.remove("number:decimal-places");
-		// fall-through intended
+			WPS_FALLTHROUGH;
 		case 1: // decimal
 			propList.insert("librevenge:value-type", "number");
 			break;
@@ -355,6 +374,10 @@ int WPSCellFormat::compare(WPSCellFormat const &cell, bool onlyNumbering) const
 	if (diff) return diff;
 	diff = int(m_vAlign) - int(cell.m_vAlign);
 	if (diff) return diff;
+	diff = int(m_wrapping) - int(cell.m_wrapping);
+	if (diff) return diff;
+	if (m_rotation<cell.m_rotation) return 1;
+	if (m_rotation>cell.m_rotation) return -1;
 	if (m_backgroundColor<cell.m_backgroundColor) return 1;
 	if (m_backgroundColor>cell.m_backgroundColor) return -1;
 	if (m_protected !=cell.m_protected) return m_protected ? 1 : -1;
@@ -404,6 +427,20 @@ std::ostream &operator<<(std::ostream &o, WPSCellFormat const &cell)
 	default:
 		break; // default
 	}
+	switch (cell.m_wrapping)
+	{
+	case WPSCellFormat::WRAP_WRAP:
+		o << "wrap,";
+		break;
+	case WPSCellFormat::WRAP_NO_WRAP:
+		o << "wrap[no],";
+		break;
+	case WPSCellFormat::WRAP_DEFAULT:
+	default:
+		break;
+	}
+	if (cell.m_rotation)
+		o << "rotation=" << cell.m_rotation << ",";
 	int subForm = cell.m_subFormat;
 	switch (cell.m_format)
 	{
