@@ -106,12 +106,12 @@ bool readDouble4(RVNGInputStreamPtr &input, double &res, bool &isNaN)
 		(first&3)==3: Can this exist ? What does this mean: 100*a basic int ?
 		The other bytes seem to have classic meaning...
 	*/
-	int first = (int) readU8(input);
+	auto first = (int) readU8(input);
 	if ((first&3)==2)
 	{
 		// so read it as a normal number
 		input->seek(-1, librevenge::RVNG_SEEK_CUR);
-		long val=long(readU16(input)>>2);
+		auto val=long(readU16(input)>>2);
 		val+=long(readU16(input))<<14;
 		if (val&0x20000000)
 			res = double(val-0x40000000);
@@ -120,7 +120,7 @@ bool readDouble4(RVNGInputStreamPtr &input, double &res, bool &isNaN)
 		return true;
 	}
 	mantisse = float(first & 0xFC)/256.f + (float) readU8(input);
-	int mantExp = (int) readU8(input);
+	auto mantExp = (int) readU8(input);
 	mantisse = (mantisse/256.f + float(0x10+(mantExp & 0x0F)))/16.f;
 	int exp = ((mantExp&0xF0)>>4)+int(readU8(input)<<4);
 	int sign = 1;
@@ -185,7 +185,7 @@ bool readDouble8(RVNGInputStreamPtr &input, double &res, bool &isNaN)
 	double mantisse = 0;
 	for (int i = 0; i < 6; i++)
 		mantisse = mantisse/256 + (double)readU8(input);
-	int mantExp = (int) readU8(input);
+	auto mantExp = (int) readU8(input);
 	mantisse = (mantisse/256 + double(0x10+(mantExp & 0x0F)))/16;
 	int exp = ((mantExp&0xF0)>>4)+int(readU8(input)<<4);
 	int sign = 1;
@@ -236,7 +236,7 @@ bool readDouble10(RVNGInputStreamPtr &input, double &res, bool &isNaN)
 	double mantisse = 0;
 	for (int i = 0; i < 8; i++)
 		mantisse = mantisse/256 + (double)readU8(input)/128;
-	int exp = (int)readU16(input);
+	auto exp = (int)readU16(input);
 	int sign = 1;
 	if (exp & 0x8000)
 	{
@@ -282,7 +282,7 @@ bool readDouble2Inv(RVNGInputStreamPtr &input, double &res, bool &isNaN)
 		return false;
 	}
 	input->seek(pos, librevenge::RVNG_SEEK_SET);
-	int val=(int) libwps::readU16(input);
+	auto val=(int) libwps::readU16(input);
 	int exp=val&0xf;
 	if ((exp&1)==1)
 	{
@@ -312,9 +312,9 @@ bool readDouble4Inv(RVNGInputStreamPtr &input, double &res, bool &isNaN)
 		return false;
 	}
 	input->seek(pos, librevenge::RVNG_SEEK_SET);
-	long val=(long) libwps::readU32(input);
-	int exp=int(val&0xf);
-	int mantisse=int(val>>6);
+	auto val=(long) libwps::readU32(input);
+	auto exp=int(val&0xf);
+	auto mantisse=int(val>>6);
 	if (val&0x20)
 		mantisse *= -1;
 	if (exp)
@@ -336,7 +336,7 @@ bool readData(RVNGInputStreamPtr &input, unsigned long size, librevenge::RVNGBin
 
 	const unsigned char *readData;
 	unsigned long sizeRead;
-	if ((readData=input->read(size, sizeRead)) == 0 || sizeRead!=size)
+	if ((readData=input->read(size, sizeRead)) == nullptr || sizeRead!=size)
 		return false;
 	data.append(readData, sizeRead);
 
@@ -392,7 +392,7 @@ WPSColor WPSColor::barycenter(float alpha, WPSColor const &colA,
 		float val=alpha*float((colA.m_value>>depl)&0xFF)+beta*float((colB.m_value>>depl)&0xFF);
 		if (val < 0) val=0;
 		if (val > 256) val=256;
-		unsigned char comp= (unsigned char)val;
+		auto comp= (unsigned char)val;
 		res+=uint32_t(comp<<depl);
 	}
 	return WPSColor(res);
@@ -400,8 +400,8 @@ WPSColor WPSColor::barycenter(float alpha, WPSColor const &colA,
 
 std::ostream &operator<< (std::ostream &o, WPSColor const &c)
 {
-	const std::streamsize width = o.width();
-	const char fill = o.fill();
+	auto const  width = o.width();
+	auto const fill = o.fill();
 	o << "#" << std::hex << std::setfill('0') << std::setw(6)
 	  << (c.m_value&0xFFFFFF)
 	  // std::ios::width() takes/returns std::streamsize (long), but
@@ -484,7 +484,7 @@ librevenge::RVNGString WPSField::getString() const
 			else
 				format="%I:%M:%S %p";
 		}
-		time_t now = time(0L);
+		time_t now = time(nullptr);
 		struct tm timeinfo;
 		if (localtime_r(&now, &timeinfo))
 		{
@@ -580,8 +580,8 @@ bool WPSBorder::addTo(librevenge::RVNGPropertyList &propList, std::string const
 		return true;
 	}
 	double totalWidth=0;
-	for (size_t w=0; w < numRelWidth; w++)
-		totalWidth+=m_widthsList[w];
+	for (auto const &w : m_widthsList)
+		totalWidth+=w;
 	if (totalWidth <= 0)
 	{
 		WPS_DEBUG_MSG(("WPSBorder::addTo: can not compute total width\n"));
@@ -597,7 +597,7 @@ bool WPSBorder::addTo(librevenge::RVNGPropertyList &propList, std::string const
 	}
 	field.str("");
 	field << "style:border-line-width";
-	if (which.length())
+	if (!which.empty())
 		field << "-" << which;
 	propList.insert(field.str().c_str(), stream.str().c_str());
 	return true;
@@ -655,8 +655,8 @@ std::ostream &operator<< (std::ostream &o, WPSBorder const &border)
 	if (numRelWidth)
 	{
 		o << "bordW[rel]=[";
-		for (size_t i=0; i < numRelWidth; i++)
-			o << border.m_widthsList[i] << ",";
+		for (auto const &w : border.m_widthsList)
+			o << w << ",";
 		o << "]:";
 	}
 	o << border.m_extra;
@@ -699,13 +699,15 @@ bool WPSEmbeddedObject::addTo(librevenge::RVNGPropertyList &propList) const
 std::ostream &operator<<(std::ostream &o, WPSEmbeddedObject const &pict)
 {
 	if (pict.isEmpty()) return o;
+	if (pict.m_size!=Vec2f())
+		o << "size=" << pict.m_size << ",";
 	o << "[";
-	for (size_t i=0; i<pict.m_typeList.size(); ++i)
+	for (auto const &type : pict.m_typeList)
 	{
-		if (pict.m_typeList[i].empty())
+		if (type.empty())
 			o << "_,";
 		else
-			o << pict.m_typeList[i] << ",";
+			o << type << ",";
 	}
 	o << "],";
 	return o;
@@ -772,9 +774,9 @@ void appendUnicode(uint32_t val, librevenge::RVNGString &buffer)
 // a little geometry
 WPSTransformation WPSTransformation::rotation(float angle, Vec2f const &center)
 {
-	float angl=float(double(angle)*M_PI/180);
-	float cosA=float(std::cos(angl));
-	float sinA=float(std::sin(angl));
+	auto angl=float(double(angle)*M_PI/180);
+	auto cosA=float(std::cos(angl));
+	auto sinA=float(std::sin(angl));
 	return WPSTransformation(WPSVec3f(cosA, -sinA, center[0]-cosA*center[0]+sinA*center[1]),
 	                         WPSVec3f(sinA, cosA, center[1]-sinA*center[0]-cosA*center[1]));
 }
@@ -828,12 +830,28 @@ bool WPSTransformation::decompose(float &rot, Vec2f &shearing, WPSTransformation
 }
 
 ////////////////////////////////////////////////////////////
-// password utility
+// utility
 ////////////////////////////////////////////////////////////
 
 namespace libwps
 {
-//! try to encode a lotus file
+std::string getCellName(Vec2i const &cellPos, Vec2b const &relative)
+{
+	if (cellPos[0]<0 || cellPos[0]>=26*26*26 || cellPos[1]<0)
+	{
+		WPS_DEBUG_MSG(("libwps::getCellName: invalid cell position\n"));
+		return "";
+	}
+	std::stringstream o;
+	if (!relative[0]) o << "$";
+	if (cellPos[0]>=26*26) o << (char)(cellPos[0]/26/26-1 + 'A');
+	if (cellPos[0]>=26) o << (char)((cellPos[0]%(26*26))/26-1 + 'A');
+	o << (char)(cellPos[0]%26+'A');
+	if (!relative[1]) o << "$";
+	o << cellPos[1]+1;
+	return o.str();
+}
+
 bool encodeLotusPassword(char const *password, uint16_t &key, std::vector<uint8_t> &keys, uint8_t const(&defValues)[16])
 {
 	if (!password)
@@ -848,7 +866,7 @@ bool encodeLotusPassword(char const *password, uint16_t &key, std::vector<uint8_
 	{
 		if (password[i]==0)
 			break;
-		uint8_t c=uint8_t(password[i]);
+		auto c=uint8_t(password[i]);
 		key=uint16_t(key^c);
 		val=uint16_t((val&0xFF)|(key<<8));
 		val=uint16_t(((val<<4)&0xFFF0)|(val>>12));
