@@ -32,6 +32,7 @@
 #include <cmath>
 #include <iostream>
 #include <map>
+#include <memory>
 #include <string>
 #include <vector>
 
@@ -53,7 +54,7 @@ typedef unsigned int uint32_t;
 #  include <inttypes.h>
 #endif /* _MSC_VER || __DJGPP__*/
 
-/* ---------- memory  --------------- */
+/* ---------- time/...  --------------- */
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
@@ -65,18 +66,7 @@ typedef unsigned int uint32_t;
 #  define localtime_r(tp,tmp) (localtime(tp)?(*(tmp)=*localtime(tp),(tmp)):0)
 #endif
 
-#if defined(SHAREDPTR_TR1)
-#include <tr1/memory>
-using std::tr1::shared_ptr;
-#elif defined(SHAREDPTR_STD)
-#include <memory>
-using std::shared_ptr;
-#else
-#include <boost/shared_ptr.hpp>
-using boost::shared_ptr;
-#endif
-
-/** a noop deleter used to transform a librevenge pointer in a false shared_ptr */
+/** a noop deleter used to transform a librevenge pointer in a false std::shared_ptr */
 template <class T>
 struct WPS_shared_ptr_noop_deleter
 {
@@ -84,22 +74,17 @@ struct WPS_shared_ptr_noop_deleter
 };
 
 /** fall through attributes */
-#define WPS_FALLTHROUGH
-#if defined(__clang__)
-#  if defined(__has_cpp_attribute) && __has_cpp_attribute(clang::fallthrough)
-#    undef WPS_FALLTHROUGH
-#    define WPS_FALLTHROUGH [[clang::fallthrough]]
-#  endif
-#elif defined(__GNUC__)
-#  if __GNUC__>=7
-#    undef WPS_FALLTHROUGH
-#    define WPS_FALLTHROUGH __attribute__ ((fallthrough))
-#  endif
+#if defined(HAVE_CLANG_ATTRIBUTE_FALLTHROUGH)
+#  define WPS_FALLTHROUGH [[clang::fallthrough]]
+#elif defined(HAVE_GCC_ATTRIBUTE_FALLTHROUGH)
+#  define WPS_FALLTHROUGH __attribute__((fallthrough))
+#else
+#  define WPS_FALLTHROUGH ((void) 0)
 #endif
 
 // basic classes and autoptr
 /** shared pointer to librevenge::RVNGInputStream */
-typedef shared_ptr<librevenge::RVNGInputStream> RVNGInputStreamPtr;
+typedef std::shared_ptr<librevenge::RVNGInputStream> RVNGInputStreamPtr;
 
 struct WPSStream;
 class WPSCell;
@@ -115,26 +100,29 @@ class WKSContentListener;
 class WKSSubDocument;
 
 /** shared pointer to WPSCell */
-typedef shared_ptr<WPSCell> WPSCellPtr;
+typedef std::shared_ptr<WPSCell> WPSCellPtr;
 /** shared pointer to WPSListener */
-typedef shared_ptr<WPSListener> WPSListenerPtr;
+typedef std::shared_ptr<WPSListener> WPSListenerPtr;
 /** shared pointer to WPSContentListener */
-typedef shared_ptr<WPSContentListener> WPSContentListenerPtr;
+typedef std::shared_ptr<WPSContentListener> WPSContentListenerPtr;
 /** shared pointer to WPSHeader */
-typedef shared_ptr<WPSHeader> WPSHeaderPtr;
+typedef std::shared_ptr<WPSHeader> WPSHeaderPtr;
 /** shared pointer to WPSSubDocument */
-typedef shared_ptr<WPSSubDocument> WPSSubDocumentPtr;
+typedef std::shared_ptr<WPSSubDocument> WPSSubDocumentPtr;
 
 /** shared pointer to WKSContentListener */
-typedef shared_ptr<WKSContentListener> WKSContentListenerPtr;
+typedef std::shared_ptr<WKSContentListener> WKSContentListenerPtr;
 /** shared pointer to WKSSubDocument */
-typedef shared_ptr<WKSSubDocument> WKSSubDocumentPtr;
+typedef std::shared_ptr<WKSSubDocument> WKSSubDocumentPtr;
 
-#if defined(__clang__) || defined(__GNUC__)
-#  define WPS_ATTRIBUTE_PRINTF(fmt, arg) __attribute__((__format__(__printf__, fmt, arg)))
+#if defined(HAVE_FUNC_ATTRIBUTE_FORMAT)
+#  define WPS_ATTRIBUTE_PRINTF(fmt, arg) __attribute__((format(printf, fmt, arg)))
 #else
 #  define WPS_ATTRIBUTE_PRINTF(fmt, arg)
 #endif
+
+#define WPS_N_ELEMENTS(m) sizeof(m)/sizeof(m[0])
+
 /* ---------- debug  --------------- */
 #ifdef DEBUG
 namespace libwps
@@ -187,28 +175,28 @@ int8_t read8(librevenge::RVNGInputStream *input);
 int16_t read16(librevenge::RVNGInputStream *input);
 int32_t read32(librevenge::RVNGInputStream *input);
 
-inline uint8_t readU8(RVNGInputStreamPtr &input)
+inline uint8_t readU8(RVNGInputStreamPtr const &input)
 {
 	return readU8(input.get());
 }
-inline uint16_t readU16(RVNGInputStreamPtr &input)
+inline uint16_t readU16(RVNGInputStreamPtr const &input)
 {
 	return readU16(input.get());
 }
-inline uint32_t readU32(RVNGInputStreamPtr &input)
+inline uint32_t readU32(RVNGInputStreamPtr const &input)
 {
 	return readU32(input.get());
 }
 
-inline int8_t read8(RVNGInputStreamPtr &input)
+inline int8_t read8(RVNGInputStreamPtr const &input)
 {
 	return read8(input.get());
 }
-inline int16_t read16(RVNGInputStreamPtr &input)
+inline int16_t read16(RVNGInputStreamPtr const &input)
 {
 	return read16(input.get());
 }
-inline int32_t read32(RVNGInputStreamPtr &input)
+inline int32_t read32(RVNGInputStreamPtr const &input)
 {
 	return read32(input.get());
 }
@@ -257,7 +245,7 @@ namespace libwps
 {
 enum NumberingType { NONE, BULLET, ARABIC, LOWERCASE, UPPERCASE, LOWERCASE_ROMAN, UPPERCASE_ROMAN };
 std::string numberingTypeToString(NumberingType type);
-enum SubDocumentType { DOC_NONE, DOC_HEADER_FOOTER, DOC_NOTE, DOC_TABLE, DOC_TEXT_BOX, DOC_COMMENT_ANNOTATION };
+enum SubDocumentType { DOC_NONE, DOC_HEADER_FOOTER, DOC_NOTE, DOC_TABLE, DOC_TEXT_BOX, DOC_COMMENT_ANNOTATION, DOC_CHART_ZONE };
 enum Justification { JustificationLeft, JustificationFull, JustificationCenter,
                      JustificationRight, JustificationFullAllLines
                    };
@@ -266,7 +254,10 @@ enum { NoBreakBit = 0x1, NoBreakWithNextBit=0x2};
 
 struct WPSColumnDefinition
 {
-	WPSColumnDefinition() : m_width(0), m_leftGutter(0), m_rightGutter(0)
+	WPSColumnDefinition()
+		: m_width(0)
+		, m_leftGutter(0)
+		, m_rightGutter(0)
 	{
 	}
 	double m_width;
@@ -276,7 +267,9 @@ struct WPSColumnDefinition
 
 struct WPSColumnProperties
 {
-	WPSColumnProperties() : m_attributes(0), m_alignment(0)
+	WPSColumnProperties()
+		: m_attributes(0)
+		, m_alignment(0)
 	{
 	}
 	uint32_t m_attributes;
@@ -295,12 +288,20 @@ struct WPSColor
 		m_value(uint32_t((a<<24)+(r<<16)+(g<<8)+b))
 	{
 	}
+	//! copy constructor
+	WPSColor(WPSColor const &) = default;
+	//! move assignement
+	WPSColor(WPSColor &&) = default;
 	//! operator=
 	WPSColor &operator=(uint32_t argb)
 	{
 		m_value = argb;
 		return *this;
 	}
+	//! operator=
+	WPSColor &operator=(WPSColor const &) = default;
+	//! move operator=
+	WPSColor &operator=(WPSColor &&) = default;
 	//! return the back color
 	static WPSColor black()
 	{
@@ -400,7 +401,19 @@ struct WPSBorder
 	enum { LeftBit = 0x01,  RightBit = 0x02, TopBit=0x4, BottomBit = 0x08 };
 
 	//! constructor
-	WPSBorder() : m_style(Simple), m_type(Single), m_width(1), m_widthsList(), m_color(WPSColor::black()), m_extra("") { }
+	WPSBorder()
+		: m_style(Simple)
+		, m_type(Single)
+		, m_width(1)
+		, m_widthsList()
+		, m_color(WPSColor::black())
+		, m_extra("") { }
+
+	WPSBorder(WPSBorder const &) = default;
+	WPSBorder(WPSBorder &&) = default;
+	WPSBorder &operator=(WPSBorder const &) = default;
+	WPSBorder &operator=(WPSBorder &&) = default;
+
 	/** add the border property to proplist (if needed )
 
 		\note if set which must be equal to "left", "top", ... */
@@ -415,7 +428,7 @@ struct WPSBorder
 	bool operator==(WPSBorder const &orig) const
 	{
 		return m_style == orig.m_style && m_type == orig.m_type && m_width == orig.m_width
-		       && m_color == orig.m_color;
+		       && m_color == orig.m_color && m_widthsList==orig.m_widthsList;
 	}
 	//! operator!=
 	bool operator!=(WPSBorder const &orig) const
@@ -445,57 +458,6 @@ struct WPSBorder
 	std::string m_extra;
 };
 
-/** small class use to define a embedded object
-
-    \note mainly used to store picture
- */
-struct WPSEmbeddedObject
-{
-	//! empty constructor
-	WPSEmbeddedObject() : m_dataList(), m_typeList()
-	{
-	}
-	//! constructor
-	WPSEmbeddedObject(librevenge::RVNGBinaryData const &binaryData,
-	                  std::string type="image/pict") : m_dataList(), m_typeList()
-	{
-		add(binaryData, type);
-	}
-	//! destructor
-	virtual ~WPSEmbeddedObject()
-	{
-	}
-	//! return true if the picture contains no data
-	bool isEmpty() const
-	{
-		for (size_t i=0; i<m_dataList.size(); ++i)
-		{
-			if (!m_dataList[i].empty())
-				return false;
-		}
-		return true;
-	}
-	//! add a picture
-	void add(librevenge::RVNGBinaryData const &binaryData, std::string type="image/pict")
-	{
-		size_t pos=m_dataList.size();
-		if (pos<m_typeList.size()) pos=m_typeList.size();
-		m_dataList.resize(pos+1);
-		m_dataList[pos]=binaryData;
-		m_typeList.resize(pos+1);
-		m_typeList[pos]=type;
-	}
-	/** add the link property to proplist */
-	bool addTo(librevenge::RVNGPropertyList &propList) const;
-	/** operator<<*/
-	friend std::ostream &operator<<(std::ostream &o, WPSEmbeddedObject const &pict);
-
-	//! the picture content: one data by representation
-	std::vector<librevenge::RVNGBinaryData> m_dataList;
-	//! the picture type: one type by representation
-	std::vector<std::string> m_typeList;
-};
-
 //! a field
 struct WPSField
 {
@@ -503,9 +465,17 @@ struct WPSField
 	enum Type { None, Database, Date, Link, PageCount, PageNumber, PageNumberNext, Time, Title };
 
 	/** basic constructor */
-	explicit WPSField(Type type) : m_type(type), m_DTFormat(""), m_numberingType(libwps::ARABIC), m_data("")
+	explicit WPSField(Type type)
+		: m_type(type)
+		, m_DTFormat("")
+		, m_numberingType(libwps::ARABIC)
+		, m_data("")
 	{
 	}
+	WPSField(WPSField &&) = default;
+	WPSField(WPSField const &) = default;
+	WPSField &operator=(WPSField const &) = default;
+	WPSField &operator=(WPSField &&) = default;
 	/** add the link property to proplist (if possible) */
 	bool addTo(librevenge::RVNGPropertyList &propList) const;
 	//! returns a string corresponding to the field (if possible) */
@@ -565,10 +535,9 @@ template <class T> class Vec2
 {
 public:
 	//! constructor
-	Vec2(T xx=0,T yy=0) : m_x(xx), m_y(yy) { }
+	explicit Vec2(T xx=0,T yy=0) : m_x(xx), m_y(yy) { }
 	//! generic copy constructor
-	template <class U> Vec2(Vec2<U> const &p) : m_x(T(p.x())), m_y(T(p.y())) {}
-
+	template <class U> explicit Vec2(Vec2<U> const &p) : m_x(T(p.x())), m_y(T(p.y())) {}
 	//! first element
 	T x() const
 	{
@@ -741,13 +710,13 @@ template <class T> class WPSBox2
 {
 public:
 	//! constructor
-	WPSBox2(Vec2<T> minPt=Vec2<T>(), Vec2<T> maxPt=Vec2<T>())
+	explicit WPSBox2(Vec2<T> minPt=Vec2<T>(), Vec2<T> maxPt=Vec2<T>())
 	{
 		m_pt[0] = minPt;
 		m_pt[1] = maxPt;
 	}
 	//! generic constructor
-	template <class U> WPSBox2(WPSBox2<U> const &p)
+	template <class U> explicit WPSBox2(WPSBox2<U> const &p)
 	{
 		for (int c=0; c < 2; c++) m_pt[c] = p[c];
 	}
@@ -934,7 +903,7 @@ public:
 		m_val[2] = zz;
 	}
 	//! generic copy constructor
-	template <class U> WPSVec3(WPSVec3<U> const &p)
+	template <class U> explicit WPSVec3(WPSVec3<U> const &p)
 	{
 		for (int c = 0; c < 3; c++) m_val[c] = T(p[c]);
 	}
@@ -1014,7 +983,7 @@ public:
 	template <class U>
 	WPSVec3<T> &operator*=(U scale)
 	{
-		for (int c = 0; c < 3; c++) m_val[c] = T(m_val[c]*scale);
+		for (auto &c : m_val) c = T(c*scale);
 		return *this;
 	}
 
@@ -1099,15 +1068,81 @@ typedef WPSVec3<int> WPSVec3i;
 /*! \brief WPSVec3 of float */
 typedef WPSVec3<float> WPSVec3f;
 
+
+/** small class use to define a embedded object
+
+    \note mainly used to store picture
+ */
+struct WPSEmbeddedObject
+{
+	//! empty constructor
+	WPSEmbeddedObject() : m_size(), m_dataList(), m_typeList(), m_sent(false)
+	{
+	}
+	WPSEmbeddedObject(WPSEmbeddedObject const &) = default;
+	WPSEmbeddedObject &operator=(WPSEmbeddedObject const &) = default;
+	WPSEmbeddedObject(WPSEmbeddedObject &&) = default;
+	WPSEmbeddedObject &operator=(WPSEmbeddedObject &&) = default;
+	//! constructor
+	WPSEmbeddedObject(librevenge::RVNGBinaryData const &binaryData,
+	                  std::string const &type="image/pict") : m_size(), m_dataList(), m_typeList(), m_sent(false)
+	{
+		add(binaryData, type);
+	}
+	//! destructor
+	virtual ~WPSEmbeddedObject()
+	{
+	}
+	//! return true if the picture contains no data
+	bool isEmpty() const
+	{
+		for (auto const &data : m_dataList)
+		{
+			if (!data.empty())
+				return false;
+		}
+		return true;
+	}
+	//! add a picture
+	void add(librevenge::RVNGBinaryData const &binaryData, std::string const &type="image/pict")
+	{
+		size_t pos=m_dataList.size();
+		if (pos<m_typeList.size()) pos=m_typeList.size();
+		m_dataList.resize(pos+1);
+		m_dataList[pos]=binaryData;
+		m_typeList.resize(pos+1);
+		m_typeList[pos]=type;
+	}
+	/** add the link property to proplist */
+	bool addTo(librevenge::RVNGPropertyList &propList) const;
+	/** operator<<*/
+	friend std::ostream &operator<<(std::ostream &o, WPSEmbeddedObject const &pict);
+
+	//! the picture size in inches(if known)
+	Vec2f m_size;
+	//! the picture content: one data by representation
+	std::vector<librevenge::RVNGBinaryData> m_dataList;
+	//! the picture type: one type by representation
+	std::vector<std::string> m_typeList;
+	//! a mutable flag which can be used to know if the picture was send to a listener
+	mutable bool m_sent;
+};
+
 /** a transformation which stored the first row of a 3x3 perspective matrix */
 class WPSTransformation
 {
 public:
 	//! constructor
-	explicit WPSTransformation(WPSVec3f const &xRow=WPSVec3f(1,0,0), WPSVec3f const &yRow=WPSVec3f(0,1,0)) : m_data(xRow, yRow), m_isIdentity(false)
+	explicit WPSTransformation(WPSVec3f const &xRow=WPSVec3f(1,0,0), WPSVec3f const &yRow=WPSVec3f(0,1,0))
+		: m_data(xRow, yRow)
+		, m_isIdentity(false)
 	{
 		checkIdentity();
 	}
+	WPSTransformation(WPSTransformation const &)=default;
+	WPSTransformation(WPSTransformation &&)=default;
+	WPSTransformation &operator=(WPSTransformation const &)=default;
+	WPSTransformation &operator=(WPSTransformation &&)=default;
 	//! returns true if the matrix is an identity matrix
 	bool isIdentity() const
 	{
@@ -1243,12 +1278,14 @@ protected:
 };
 
 //
-// password utility
+// utility
 //
 
 namespace libwps
 {
-//! try to encode a lotus file
+//! returns the cell name corresponding to a cell's position
+std::string getCellName(Vec2i const &cellPos, Vec2b const &relative=Vec2b(true,true));
+//! returns the checksum and the keys (to encode a lotus file) given a password file
 bool encodeLotusPassword(char const *password, uint16_t &key, std::vector<uint8_t> &keys, uint8_t const(&defValues)[16]);
 }
 #endif /* LIBWPS_INTERNAL_H */
